@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.063';
+$Config::Model::VERSION = '2.064';
 use Mouse;
 use Mouse::Util::TypeConstraints;
 use MouseX::StrictConstructor;
@@ -217,11 +217,17 @@ sub instance_names {
 # description, summary, level, status are moved
 # into element description.
 
-my @legal_params = qw/element status description summary level
-    config_dir
-    read_config read_config_dir write_config
-    write_config_dir accept/;
-my @static_legal_params = qw/class_description copyright author license generated_by/;
+my @legal_params_to_move = (
+    qw/read_config  read_config_dir
+       write_config write_config_dir/,    # read/write stuff
+
+    # this parameter is filled by class generated by a program. It may
+    # be used to avoid interactive edition of a generated model
+    'generated_by',
+    qw/class_description author copyright license include include_after class/
+);
+
+my @other_legal_params = qw/ author element status description summary level accept/;
 
 # keep as external API. All internal call go through _store_model
 #  See comments around raw_models attribute for explanations
@@ -328,17 +334,7 @@ sub normalize_class_parameters {
     $model->{read_config_dir} = $model->{write_config_dir} = delete $normalized_model->{config_dir}
         if defined $normalized_model->{config_dir};
 
-    my @info_to_move = (
-        qw/read_config  read_config_dir
-            write_config write_config_dir/,    # read/write stuff
-
-        # this parameter is filled by class generated by a program. It may
-        # be used to avoid interactive edition of a generated model
-        'generated_by',
-        qw/class_description author copyright license include include_after/
-    );
-
-    foreach my $info (@info_to_move) {
+    foreach my $info (@legal_params_to_move) {
         next unless defined $normalized_model->{$info};
         $model->{$info} = delete $normalized_model->{$info};
     }
@@ -429,7 +425,7 @@ sub normalize_class_parameters {
             . "parameters '"
             . join( ', ', keys %$normalized_model ) . "' "
             . "Expected '"
-            . join( "', '", @legal_params, @static_legal_params )
+            . join( "', '", @legal_params_to_move, @other_legal_params )
             . "'" )
         if keys %$normalized_model;
 
@@ -1560,7 +1556,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.063
+version 2.064
 
 =head1 SYNOPSIS
 
